#include<iostream>
#include<vector>

using namespace std;

// dist[i][k] er distansen mellom plattform i og k
vector< vector<int> > dist; 

// mem[i][k] er den optimale løsningen om i og k er de ytterste plattformene vi
// besøker og vi nå befinner oss i i
vector< vector<long long> > mem;

// Input
vector<int> a, b, e;

/*
 * Solve(i, k) løser mem[i][k] ved å se på de to måtene vi kan komme til (i, k)
 * på.
 *  - Enten så hopper man fra plattformen nærmest i, f. eks fra i+1 til i om
 * man befinner seg på venstre siden eller så
 *  - hopper man på tvers av hele intervallet fra k til i.
 * Derfor trenger man å løse de to mindre problemene (i+inc, k) og (k, i+inc).
 * inc brukes ut i fra om i er på venstre eller høyre side av start posisjonen.
 *
 * Denne løsningen tar i bruk en teknikk som kalles memoizering. En kan da løse
 * problemet som ved brute force, bare at man tar vare på verdiene funksjonen
 * beregner slik at vi bare løser hvert problem en gang. For at dette skal
 * fungere bra må vi ha plass til å lagre løsningsrommet, noe som i dette
 * tilfellet ikke er noe problem!
 *
 * Merk av vi i main løser alle tilfellene som hvor det ene ytterpunktet er
 * pos. Dette gjør at vi alltid kommer til en verdi som allerede er beregnet og
 * rekursjonen slutter. Koden som løser disse tilfellene er tilstrekkelig til å
 * oppnå 40% score.
 */
long long solve(int i, int k)
{
    // Not computed before
    if(mem[i][k] == -2) {
        int inc = (i < k ? 1 : -1);
        long long s = solve(i+inc, k) - dist[i][i+inc];
        long long c = solve(k, i+inc) - dist[i][k];

        mem[i][k] = max(s, c);
        if(mem[i][k] > -1)
            mem[i][k] += e[i];
    }

    return mem[i][k];
}

int main()
{
    // Read input
    int P;
    cin >> P;

    a = vector<int>(P);
    b = vector<int>(P);
    e = vector<int>(P);
    dist = vector< vector<int> >(P, vector<int>(P));
    mem = vector< vector<long long> >(P, vector<long long>(P, -2));

    for(int i = 0; i < P; ++i)
        cin >> a[i] >> b[i] >> e[i];

    int pos, E;
    cin >> pos >> E;

    // Find my position
    for(int i = 0; i < P; ++i) {
        if(a[i] <= pos && pos <= b[i]) {
            pos = i;
            break;
        }
    }

    // Compute distances
    for(int i = 0; i < P; ++i) {
        dist[i][i] = 0;
        for(int k = i+1; k < P; ++k)
            dist[i][k] = dist[k][i] = dist[i][k-1] + a[k] - b[k-1];
    }

    // Set initial cases
    mem[pos][pos] = E + e[pos];
    for(int l = pos-1; l >= 0; --l) {
        if(mem[l+1][pos]-dist[l+1][l] >= 0)
            mem[l][pos] = mem[l+1][pos] - dist[l][l+1] + e[l];
        else
            mem[l][pos] = -1;

        mem[pos][l] = max(-1LL, mem[l][pos] - dist[l][pos]);
    }

    for(int r = pos+1; r < P; ++r) {
        if(mem[r-1][pos]-dist[r-1][r] >= 0)
            mem[r][pos] = mem[r-1][pos] - dist[r-1][r] + e[r];
        else
            mem[r][pos] = -1;

        mem[pos][r] = max(-1LL, mem[r][pos] - dist[r][pos]);
    }

    // Compute answer
    long long best = 0;
    for(int l = 0; l <= pos; ++l) {
        for(int r = pos; r < P; ++r) {
            solve(l, r);
            solve(r, l);

            best = max(best, max(mem[l][r], mem[r][l]));
        }
    }

    cout << best << endl;

    return 0;
}
